package hdl

import (
	"applet/app/e"
	"applet/app/lib/validate"
	"applet/app/md"
	"applet/app/svc"
	"github.com/gin-gonic/gin"
)

// GenerateDataList
// @Summary    	 分成数据-列表
// @Tags         数据中心------嘉俊
// @Description  数据中心-分成数据-列表
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.DataCenterGenerateDataReq   true   "请求参数"
// @Success      200   {object}	  md.DataCenterGenerateDataRes     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/dataCenter/generate/data/list [POST]
func GenerateDataList(c *gin.Context) {
	var req md.DataCenterGenerateDataReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	res := svc.DataCenterGenerateDataList(c, req)
	e.OutSuc(c, res, nil)
	return
}

// IncomeDataList
// @Summary    	 收益报表-列表
// @Tags         数据中心------嘉俊
// @Description  数据中心-收益报表-列表
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.DataCenterGenerateDataReq   true   "请求参数"
// @Success      200   {object}	  md.DataCenterIncomeDataRes     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/dataCenter/income/data/list [POST]
func IncomeDataList(c *gin.Context) {
	var req md.DataCenterGenerateDataReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	res := svc.DataCenterIncomeDataList(c, req)
	e.OutSuc(c, res, nil)
	return
}

// IncomeDataDetail
// @Summary    	 收益报表-详情
// @Tags         数据中心------嘉俊
// @Description  数据中心-收益报表-详情
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.DataCenterGenerateDataCommReq   true   "请求参数"
// @Success      200   {object}	  md.DataCenterIncomeDataDetail     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/dataCenter/income/data/detail [POST]
func IncomeDataDetail(c *gin.Context) {
	var req md.DataCenterGenerateDataCommReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	svc.DataCenterIncomeDataDetail(c, req)
}

// GenerateDataDel
// @Summary    	 分成数据-删除
// @Tags         数据中心------嘉俊
// @Description  数据中心-分成数据-删除
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.DataCenterGenerateDataCommReq   true   "请求参数"
// @Success      200   {string}	      "具体看返回内容 "
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/dataCenter/generate/data/del [POST]
func GenerateDataDel(c *gin.Context) {
	var req md.DataCenterGenerateDataCommReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	res := svc.DataCenterGenerateDataDel(c, req)
	e.OutSuc(c, res, nil)
	return
}

// GenerateDataDoing
// @Summary    	 分成数据-应用操作
// @Tags         数据中心------嘉俊
// @Description  数据中心-分成数据-应用操作
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.DataCenterGenerateDataCommReq   true   "请求参数"
// @Success      200   {string}	      "具体看返回内容 "
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/dataCenter/generate/data/doing [POST]
func GenerateDataDoing(c *gin.Context) {
	var req md.DataCenterGenerateDataCommReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	res := svc.DataCenterGenerateDataDoing(c, req)
	e.OutSuc(c, res, nil)
	return
}

// GenerateDataDetail
// @Summary    	 分成数据-详情
// @Tags         数据中心------嘉俊
// @Description  数据中心-分成数据-详情
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.DataCenterGenerateDataCommReq   true   "请求参数"
// @Success      200   {object}	md.DataCenterGenerateDataDetailData     "具体看返回内容 "
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/dataCenter/generate/data/detail [POST]
func GenerateDataDetail(c *gin.Context) {
	var req md.DataCenterGenerateDataCommReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	svc.DataCenterGenerateDataDetail(c, req)
}
