package hdl

import (
	"applet/app/e"
	"applet/app/lib/validate"
	"applet/app/md"
	"applet/app/svc"
	"applet/app/utils/cache"
	"github.com/gin-gonic/gin"
)

// OriginalDataList
// @Summary    	 原始数据-列表
// @Tags         数据中心------嘉俊
// @Description  数据中心-原始数据-列表
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.DataCenterOriginalDataReq   true   "请求参数"
// @Success      200   {object}	  md.DataCenterOriginalDataRes     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/dataCenter/original/data/list [POST]
func OriginalDataList(c *gin.Context) {
	var req md.DataCenterOriginalDataReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	res := svc.DataCenterOriginalDataList(c, req)
	e.OutSuc(c, res, nil)
	return
}

// OriginalDataDel
// @Summary    	 原始数据-删除
// @Tags         数据中心------嘉俊
// @Description  数据中心-原始数据-删除
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.DataCenterOriginalDataCommReq   true   "请求参数"
// @Success      200   {string}	      "具体看返回内容 "
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/dataCenter/original/data/del [POST]
func OriginalDataDel(c *gin.Context) {
	var req md.DataCenterOriginalDataCommReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	res := svc.DataCenterOriginalDataDel(c, req)
	e.OutSuc(c, res, nil)
	return
}

// OriginalDataDoing
// @Summary    	 原始数据-应用操作
// @Tags         数据中心------嘉俊
// @Description  数据中心-原始数据-应用操作
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.DataCenterDataCenterOriginalDataDoingReq   true   "请求参数"
// @Success      200   {string}	      "具体看返回内容 "
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/dataCenter/original/data/doing [POST]
func OriginalDataDoing(c *gin.Context) {
	var req md.DataCenterDataCenterOriginalDataDoingReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	res := svc.DataCenterOriginalDataDoing(c, req)
	e.OutSuc(c, res, nil)
	return
}

// OriginalDataTotal
// @Summary    	 原始数据-记录应用时统计
// @Tags         数据中心------嘉俊
// @Description  数据中心-原始数据-记录应用时统计
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.DataCenterOriginalDataCommReq   true   "请求参数"
// @Success      200   {object} md.MediumDivisionStrategy	      "具体看返回内容 "
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/dataCenter/original/data/total [POST]
func OriginalDataTotal(c *gin.Context) {
	var req md.DataCenterOriginalDataCommReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	svc.DataCenterOriginalDataTotal(c, req)
}

// OriginalDataMoreApplication
// @Summary    	 原始数据-一键导入应用列表
// @Tags         数据中心------嘉俊
// @Description  数据中心-原始数据-一键导入应用列表
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.DataCenterOriginalDataMoreApplicationReq   true   "请求参数"
// @Success      200   {object}	  md.DataCenterOriginalDataMoreApplicationRes     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/dataCenter/original/data/more/application [POST]
func OriginalDataMoreApplication(c *gin.Context) {
	var req md.DataCenterOriginalDataMoreApplicationReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	res := svc.OriginalDataMoreApplication(c, req)
	e.OutSuc(c, res, nil)
	return
}

// OriginalDataMoreApplicationDoing
// @Summary    	 原始数据-一键导入操作
// @Tags         数据中心------嘉俊
// @Description  数据中心-原始数据-一键导入操作
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.DataCenterOriginalDataMoreApplicationDoingReq   true   "请求参数"
// @Success      200   {string}	      "具体看返回内容 "
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/dataCenter/original/data/more/application/doing [POST]
func OriginalDataMoreApplicationDoing(c *gin.Context) {
	var req md.DataCenterOriginalDataMoreApplicationDoingReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	err = svc.OriginalDataMoreApplicationDoing(c, req)
	if err != nil {
		e.OutErr(c, 400, e.NewErr(400, err.Error()))
		return
	}
	e.OutSuc(c, "success", nil)
	return
}

// OriginalDataMoreApplicationState
// @Summary    	 原始数据-一键导入操作状态
// @Tags         数据中心------嘉俊
// @Description  数据中心-原始数据-一键导入操作状态
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Success      200   {string}	      "具体看返回内容 state=1 进行中"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/dataCenter/original/data/more/application/state [GET]
func OriginalDataMoreApplicationState(c *gin.Context) {
	res := map[string]string{
		"state": "0",
	}
	state, _ := cache.GetString(c.GetString("mid") + ":original.wx.ad.data")
	if state == "1" {
		res["state"] = "1"
	}
	e.OutSuc(c, res, nil)
	return
}

// OriginalDataOneApplicationState
// @Summary    	 原始数据-单个应用数据操作后的完成状态
// @Tags         数据中心------嘉俊
// @Description  数据中心-原始数据-单个应用数据操作后的完成状态
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Success      200   {string}	      "具体看返回内容 state=1 进行中"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/dataCenter/original/data/one/application/state [GET]
func OriginalDataOneApplicationState(c *gin.Context) {
	res := map[string]string{
		"state": "0",
	}
	state, _ := cache.GetString(c.GetString("mid") + ":original.wx.ad.data")
	if state == "1" {
		res["state"] = "1"
	}
	e.OutSuc(c, res, nil)
	return
}

// OriginalDataOneApplication
// @Summary    	 原始数据-单个导入应用列表
// @Tags         数据中心------嘉俊
// @Description  数据中心-原始数据-单个导入应用列表
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Success      200   {object}	  md.DataCenterOriginalDataOneApplicationRes     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/dataCenter/original/data/one/application [GET]
func OriginalDataOneApplication(c *gin.Context) {
	svc.OriginalDataOneApplication(c)
}

// OriginalDataOneApplicationAdList
// @Summary    	 原始数据-单个导入应用-广告位列表
// @Tags         数据中心------嘉俊
// @Description  数据中心-原始数据-单个导入应用-广告位列表
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.DataCenterOriginalDataOneApplicationAdListReq   true   "请求参数"
// @Success      200   {object}	  md.DataCenterOriginalDataOneApplicationAdListRes     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/dataCenter/original/data/one/application/ad/list [POST]
func OriginalDataOneApplicationAdList(c *gin.Context) {
	var req md.DataCenterOriginalDataOneApplicationAdListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	res := svc.OriginalDataOneApplicationAdList(c, req)
	e.OutSuc(c, res, nil)
	return
}

// OriginalDataOneApplicationTotal
// @Summary    	 原始数据-单个应用数据统计
// @Tags         数据中心------嘉俊
// @Description  数据中心-原始数据-单个应用数据统计
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.DataCenterOriginalDataOneApplicationDoingReq   true   "请求参数"
// @Success      200   {object}	   md.DataCenterOriginalDataOneApplicationDoingRes   "具体看返回内容 "
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/dataCenter/original/data/one/application/total [POST]
func OriginalDataOneApplicationTotal(c *gin.Context) {
	var req md.DataCenterOriginalDataOneApplicationDoingReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	svc.OriginalDataOneApplicationTotal(c, req)
}

// OriginalDataOneApplicationDoing
// @Summary    	 原始数据-单个应用数据操作
// @Tags         数据中心------嘉俊
// @Description  数据中心-原始数据-单个应用数据操作
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.DataCenterOriginalDataOneApplicationDoingReq   true   "请求参数"
// @Success      200   {string}	      "具体看返回内容 "
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/dataCenter/original/data/one/application/doing [POST]
func OriginalDataOneApplicationDoing(c *gin.Context) {
	var req md.DataCenterOriginalDataOneApplicationDoingReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	args := md.DataCenterOriginalDataMoreApplicationDoingReq{
		Ids: []md.DataCenterOriginalDataOneApplicationDoingReqData{
			{
				AppId: req.AppId,
				AdId:  req.AdId,
			},
		},
		Date: req.Date,
	}
	err = svc.OriginalDataMoreApplicationDoing(c, args)
	if err != nil {
		e.OutErr(c, 400, e.NewErr(400, err.Error()))
		return
	}
	e.OutSuc(c, "success", nil)
	return
}
