package hdl

import (
	"applet/app/e"
	"applet/app/lib/validate"
	"applet/app/md"
	"applet/app/svc"
	"github.com/gin-gonic/gin"
)

// FinanceCenterAgentList
// @Summary    	 代理列表
// @Tags         财务中心------嘉俊
// @Description  财务中心-代理列表
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.FinanceCenterDataReq   true   "请求参数"
// @Success      200   {object}	  md.FinanceCenterDataRes     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/financeCenter/agent/list [POST]
func FinanceCenterAgentList(c *gin.Context) {
	var req md.FinanceCenterDataReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	res := svc.FinanceCenterAgentList(c, req)
	e.OutSuc(c, res, nil)
	return
}

// FinanceCenterAgentDetail
// @Summary    	 代理详情
// @Tags         财务中心------嘉俊
// @Description  财务中心-代理详情
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.CommDetailReq   true   "请求参数"
// @Success      200   {object}	  md.FinanceCenterDataAgentDetailRes     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/financeCenter/agent/detail [POST]
func FinanceCenterAgentDetail(c *gin.Context) {
	var req md.CommDetailReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	res := svc.FinanceCenterAgentDetail(c, req)
	e.OutSuc(c, res, nil)
	return
}

// FinanceCenterAgentSettleFileSave
// @Summary    	 代理详情-结算单保存
// @Tags         财务中心------嘉俊
// @Description  财务中心-代理详情-结算单保存
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.SettleFileReq   true   "请求参数"
// @Success      200   {string}	     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/financeCenter/agent/settle/file/save [POST]
func FinanceCenterAgentSettleFileSave(c *gin.Context) {
	var req md.SettleFileReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	svc.FinanceCenterAgentSettleFileSave(c, req)
}

// FinanceCenterAgentPaySave
// @Summary    	 代理详情-确认支付
// @Tags         财务中心------嘉俊
// @Description  财务中心-代理详情-确认支付
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.CommDetailReq   true   "请求参数"
// @Success      200   {string}	     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/financeCenter/agent/pay/save [POST]
func FinanceCenterAgentPaySave(c *gin.Context) {
	var req md.CommDetailReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	svc.FinanceCenterAgentPaySave(c, req)
}

// FinanceCenterAgentOtherIncomeSave
// @Summary    	 代理详情-其他收益调整
// @Tags         财务中心------嘉俊
// @Description  财务中心-代理详情-其他收益调整
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.OtherIncomeReq   true   "请求参数"
// @Success      200   {string}	     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/financeCenter/agent/other/income/save [POST]
func FinanceCenterAgentOtherIncomeSave(c *gin.Context) {
	var req md.OtherIncomeReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	svc.FinanceCenterAgentOtherIncomeSave(c, req)
}

// FinanceCenterAgentInvoiceSave
// @Summary    	 代理详情-发票保存
// @Tags         财务中心------嘉俊
// @Description  财务中心-代理详情-发票保存
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.InvoiceReq   true   "请求参数"
// @Success      200   {string}	     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/financeCenter/agent/invoice/save [POST]
func FinanceCenterAgentInvoiceSave(c *gin.Context) {
	var req md.InvoiceReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	svc.FinanceCenterAgentInvoiceSave(c, req)

}
