package hdl

import (
	"applet/app/e"
	"applet/app/lib/validate"
	"applet/app/md"
	"applet/app/svc"
	"github.com/gin-gonic/gin"
)

// FinanceCenterPlatformList
// @Summary    	 平台报表
// @Tags         财务中心------嘉俊
// @Description  财务中心-平台报表
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.FinanceCenterPlatformDataReq   true   "请求参数"
// @Success      200   {object}	  md.FinanceCenterPlatformDataRes     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/financeCenter/platform/list [POST]
func FinanceCenterPlatformList(c *gin.Context) {
	var req md.FinanceCenterPlatformDataReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	res := svc.FinanceCenterPlatformList(c, req)
	e.OutSuc(c, res, nil)
	return
}

// FinanceCenterMediumList
// @Summary    	 媒体列表
// @Tags         财务中心------嘉俊
// @Description  财务中心-媒体列表
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.FinanceCenterDataReq   true   "请求参数"
// @Success      200   {object}	  md.FinanceCenterDataRes     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/financeCenter/medium/list [POST]
func FinanceCenterMediumList(c *gin.Context) {
	var req md.FinanceCenterDataReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	res := svc.FinanceCenterMediumList(c, req)
	e.OutSuc(c, res, nil)
	return
}

// FinanceCenterMediumDetail
// @Summary    	 媒体详情
// @Tags         财务中心------嘉俊
// @Description  财务中心-媒体详情
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.CommDetailReq   true   "请求参数"
// @Success      200   {object}	  md.FinanceCenterDataDetailRes     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/financeCenter/medium/detail [POST]
func FinanceCenterMediumDetail(c *gin.Context) {
	var req md.CommDetailReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	res := svc.FinanceCenterMediumDetail(c, req)
	e.OutSuc(c, res, nil)
	return
}

// FinanceCenterMediumSettleFileSave
// @Summary    	 媒体详情-结算单保存
// @Tags         财务中心------嘉俊
// @Description  财务中心-媒体详情-结算单保存
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.SettleFileReq   true   "请求参数"
// @Success      200   {string}	     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/financeCenter/medium/settle/file/save [POST]
func FinanceCenterMediumSettleFileSave(c *gin.Context) {
	var req md.SettleFileReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	svc.FinanceCenterMediumSettleFileSave(c, req)
}

// FinanceCenterMediumPaySave
// @Summary    	 媒体详情-确认支付
// @Tags         财务中心------嘉俊
// @Description  财务中心-媒体详情-确认支付
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.CommDetailReq   true   "请求参数"
// @Success      200   {string}	     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/financeCenter/medium/pay/save [POST]
func FinanceCenterMediumPaySave(c *gin.Context) {
	var req md.CommDetailReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	svc.FinanceCenterMediumPaySave(c, req)
}

// FinanceCenterMediumOtherIncomeSave
// @Summary    	 媒体详情-其他收益调整
// @Tags         财务中心------嘉俊
// @Description  财务中心-媒体详情-其他收益调整
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.OtherIncomeReq   true   "请求参数"
// @Success      200   {string}	     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/financeCenter/medium/other/income/save [POST]
func FinanceCenterMediumOtherIncomeSave(c *gin.Context) {
	var req md.OtherIncomeReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	svc.FinanceCenterMediumOtherIncomeSave(c, req)
}

// FinanceCenterMediumInvoiceSave
// @Summary    	 媒体详情-发票保存
// @Tags         财务中心------嘉俊
// @Description  财务中心-媒体详情-发票保存
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.InvoiceReq   true   "请求参数"
// @Success      200   {string}	     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/financeCenter/medium/invoice/save [POST]
func FinanceCenterMediumInvoiceSave(c *gin.Context) {
	var req md.InvoiceReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	svc.FinanceCenterMediumInvoiceSave(c, req)

}
