package hdl

import (
	"applet/app/e"
	"applet/app/lib/validate"
	"applet/app/md"
	"applet/app/svc"
	"github.com/gin-gonic/gin"
)

// FinancialDynamicsMediumTotal
// @Summary    	 媒体预付-统计
// @Tags         资产动态------嘉俊
// @Description  资产动态-媒体预付-统计
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.FinancialDynamicsMediumTotalReq   true   "请求参数"
// @Success      200   {object}	  md.FinancialDynamicsMediumTotalRes     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/financialDynamics/medium/total [POST]
func FinancialDynamicsMediumTotal(c *gin.Context) {
	var req md.FinancialDynamicsMediumTotalReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	res := svc.FinancialDynamicsMediumTotal(c, req)
	e.OutSuc(c, res, nil)
	return
}

// FinancialDynamicsMediumList
// @Summary    	 媒体预付
// @Tags         资产动态------嘉俊
// @Description  资产动态-媒体预付
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.FinancialDynamicsMediumListReq   true   "请求参数"
// @Success      200   {object}	  md.FinancialDynamicsMediumListRes     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/financialDynamics/medium/list [POST]
func FinancialDynamicsMediumList(c *gin.Context) {
	var req md.FinancialDynamicsMediumListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	res := svc.FinancialDynamicsMediumList(c, req)
	e.OutSuc(c, res, nil)
	return
}

// FinancialDynamicsMediumSave
// @Summary    	 媒体预付-创建
// @Tags         资产动态------嘉俊
// @Description  资产动态-媒体预付-创建
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.FinancialDynamicsMediumSaveReq   true   "请求参数"
// @Success      200   {string}	       "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/financialDynamics/medium/save [POST]
func FinancialDynamicsMediumSave(c *gin.Context) {
	var req md.FinancialDynamicsMediumSaveReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	svc.FinancialDynamicsMediumSave(c, req)
}

// FinancialDynamicsAgentTotal
// @Summary    	 代理预付-统计
// @Tags         资产动态------嘉俊
// @Description  资产动态-代理预付-统计
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.FinancialDynamicsAgentTotalReq   true   "请求参数"
// @Success      200   {object}	  md.FinancialDynamicsAgentTotalRes     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/financialDynamics/agent/total [POST]
func FinancialDynamicsAgentTotal(c *gin.Context) {
	var req md.FinancialDynamicsAgentTotalReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	res := svc.FinancialDynamicsAgentTotal(c, req)
	e.OutSuc(c, res, nil)
	return
}

// FinancialDynamicsAgentList
// @Summary    	 代理预付
// @Tags         资产动态------嘉俊
// @Description  资产动态-代理预付
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.FinancialDynamicsAgentListReq   true   "请求参数"
// @Success      200   {object}	  md.FinancialDynamicsAgentListRes     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/financialDynamics/agent/list [POST]
func FinancialDynamicsAgentList(c *gin.Context) {
	var req md.FinancialDynamicsAgentListReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	res := svc.FinancialDynamicsAgentList(c, req)
	e.OutSuc(c, res, nil)
	return
}

// FinancialDynamicsAgentSave
// @Summary    	 代理预付-创建
// @Tags         资产动态------嘉俊
// @Description  资产动态-代理预付-创建
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.FinancialDynamicsAgentSaveReq   true   "请求参数"
// @Success      200   {string}	       "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/financialDynamics/agent/save [POST]
func FinancialDynamicsAgentSave(c *gin.Context) {
	var req md.FinancialDynamicsAgentSaveReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	svc.FinancialDynamicsAgentSave(c, req)
}
