package hdl

import (
	"applet/app/e"
	"applet/app/lib/validate"
	"applet/app/md"
	"applet/app/svc"
	"github.com/gin-gonic/gin"
)

// AgentList
// @Summary    	 代理列表
// @Tags         关联中心------嘉俊
// @Description  关联中心-代理列表
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.AgentQualificationEnterpriseReq   true   "请求参数"
// @Success      200   {object}	  md.AgentQualificationEnterpriseRes     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/mediumCenter/agent/list [POST]
func AgentList(c *gin.Context) {
	var req md.AgentQualificationEnterpriseReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	res := svc.AgentQualificationEnterprise(c, 0, req)
	e.OutSuc(c, res, nil)
	return
}

// AgentBindMediumList
// @Summary    	 代理绑定媒体列表
// @Tags         关联中心------嘉俊
// @Description  关联中心-代理绑定媒体列表
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.MediumListReq   true   "请求参数"
// @Success      200   {object}	  md.MediumListRes     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/mediumCenter/agent/bind/medium/list [POST]
func AgentBindMediumList(c *gin.Context) {
	svc.AgentBindMediumList(c)
	return
}

// MediumList
// @Summary    	 媒体列表
// @Tags         关联中心------嘉俊
// @Description  关联中心-媒体列表
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.MediumQualificationEnterpriseReq   true   "请求参数"
// @Success      200   {object}	  md.MediumQualificationEnterpriseRes     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/mediumCenter/medium/list [POST]
func MediumList(c *gin.Context) {
	var req md.MediumQualificationEnterpriseReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	res := svc.MediumQualificationEnterprise(c, 0, req)
	e.OutSuc(c, res, nil)
	return
}

// MediumBindAgentList
// @Summary    	 媒体绑定代理列表
// @Tags         关联中心------嘉俊
// @Description  关联中心-媒体绑定代理列表
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.MediumListReq   true   "请求参数"
// @Success      200   {object}	  md.MediumListRes     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/mediumCenter/medium/bind/agent/list [POST]
func MediumBindAgentList(c *gin.Context) {
	svc.MediumBindAgentList(c)
	return
}

// MediumBindAgentSave
// @Summary    	 媒体绑定代理操作
// @Tags         关联中心------嘉俊
// @Description  关联中心-媒体绑定代理操作
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.MediumListSaveReq   true   "请求参数"
// @Success      200   {string}	   "具体看返回内容 "
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/mediumCenter/medium/bind/agent/save [POST]
func MediumBindAgentSave(c *gin.Context) {
	svc.MediumBindAgentSave(c)
	return
}

// MediumBindAgentDel
// @Summary    	 媒体绑定代理删除
// @Tags         关联中心------嘉俊
// @Description  关联中心-媒体绑定代理删除
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.MediumListDelReq   true   "请求参数"
// @Success      200   {string}	   "具体看返回内容 "
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/mediumCenter/medium/bind/agent/del [POST]
func MediumBindAgentDel(c *gin.Context) {
	svc.MediumBindAgentDel(c)
	return
}
