package hdl

import (
	"applet/app/e"
	"applet/app/lib/validate"
	"applet/app/md"
	"applet/app/svc"
	"github.com/gin-gonic/gin"
)

// SettleCenterMediumList
// @Summary    	 媒体列表
// @Tags         结算中心------嘉俊
// @Description  结算中心-媒体列表
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.SettleCenterDataReq   true   "请求参数"
// @Success      200   {object}	  md.SettleCenterDataRes     "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/settleCenter/medium/list [POST]
func SettleCenterMediumList(c *gin.Context) {
	var req md.SettleCenterDataReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	res := svc.SettleCenterMediumList(c, req)
	e.OutSuc(c, res, nil)
	return
}

// SettleCenterMediumSave
// @Summary    	 媒体修改结算方式
// @Tags         结算中心------嘉俊
// @Description  结算中心-媒体修改结算方式
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.SettleCenterDataSaveReq   true   "请求参数"
// @Success      200   {string}	      "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/settleCenter/medium/save [POST]
func SettleCenterMediumSave(c *gin.Context) {
	var req md.SettleCenterDataSaveReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	svc.SettleCenterMediumSave(c, req)
}

// SettleCenterMediumDetail
// @Summary    	 媒体详情
// @Tags         结算中心------嘉俊
// @Description  结算中心-媒体详情
// @param Authorization header string true "验证参数Bearer和token空格拼接"
// @Accept       json
// @Produce      json
// @Param        args 	body      md.SettleCenterDataDetailReq   true   "请求参数"
// @Success      200   {object} md.SettleCenterDataDetailRes	      "具体看返回内容 这是data里面的数据"
// @Failure      400   {object}   md.Response              "具体错误"
// @Router       /api/settleCenter/medium/detail [POST]
func SettleCenterMediumDetail(c *gin.Context) {
	var req md.SettleCenterDataDetailReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	res := svc.SettleCenterMediumDetail(c, req)
	e.OutSuc(c, res, nil)
	return
}
