package md

type GetComponentAccessToken struct {
	ComponentAccessToken string `json:"component_access_token" example:"第三方平台 access_token"`
	ExpiresIn            int    `json:"expires_in"  example:"有效期，单位：秒"`
}

type GetPreAuthCode struct {
	PreAuthCode string `json:"pre_auth_code" example:"预授权码"`
	ExpiresIn   int    `json:"expires_in"  example:"有效期，单位：秒"`
}

type GetAuthorizerAccessTokenByAuthCode struct {
	AuthorizationInfo struct {
		AuthorizerAppid        string `json:"authorizer_appid" example:"授权方 appid"`
		AuthorizerAccessToken  string `json:"authorizer_access_token" example:"接口调用令牌"`
		ExpiresIn              int    `json:"expires_in" example:"authorizer_access_token 的有效期（在授权的公众号/小程序具备API权限时，才有此返回值），单位：秒"`
		AuthorizerRefreshToken string `json:"authorizer_refresh_token" example:"刷新令牌（在授权的公众号具备API权限时，才有此返回值），刷新令牌主要用于第三方平台获取和刷新已授权用户的 authorizer_access_token。一旦丢失，只能让用户重新授权，才能再次拿到新的刷新令牌。用户重新授权后，之前的刷新令牌会失效"`
	} `json:"authorization_info" example:"预授权码"`
}

type ApiAuthorizerToken struct {
	AuthorizerAccessToken  string `json:"authorizer_access_token" example:"接口调用令牌"`
	ExpiresIn              int    `json:"expires_in" example:"authorizer_access_token 的有效期（在授权的公众号/小程序具备API权限时，才有此返回值），单位：秒"`
	AuthorizerRefreshToken string `json:"authorizer_refresh_token" example:"刷新令牌（在授权的公众号具备API权限时，才有此返回值），刷新令牌主要用于第三方平台获取和刷新已授权用户的 authorizer_access_token。一旦丢失，只能让用户重新授权，才能再次拿到新的刷新令牌。用户重新授权后，之前的刷新令牌会失效"`
}

type DelAuthorize struct {
	ErrCode int    `json:"errcode" example:"错误码"`
	ErrMsg  string `json:"errmsg" example:"错误信息"`
}

type AgencyCreateAdunit struct {
	Ret      int    `json:"ret" example:"错误码"`
	ErrMsg   string `json:"err_msg" example:"错误信息"`
	AdUnitId string `json:"ad_unit_id" example:"广告单元ID"`
}

type AgencyUpdateAdunit struct {
	Ret    int    `json:"ret" example:"错误码"`
	ErrMsg string `json:"err_msg" example:"错误信息"`
}

type SetCoverAdposStatus struct {
	Ret    int    `json:"ret" example:"错误码"`
	ErrMsg string `json:"err_msg" example:"错误信息"`
}

type GetAdunitList struct {
	Ret    int    `json:"ret" example:"错误码"`
	ErrMsg string `json:"err_msg" example:"错误信息"`
	AdUnit []struct {
		AdSlot           string                   `json:"ad_slot" example:"广告位类型名称"`
		AdUnitId         string                   `json:"ad_unit_id" example:"广告单元ID"`
		AdUnitName       string                   `json:"ad_unit_name" example:"广告单元名称"`
		AdUnitSize       []map[string]interface{} `json:"ad_unit_size" example:"广告单元大小"`
		AdUnitStatus     int                      `json:"ad_unit_status" example:"广告单元开关状态 1：开启 2：关闭"`
		VideoDurationMax int                      `json:"video_duration_max" example:"广告展示时长最大值"`
		VideoDurationMin int                      `json:"video_duration_min" example:"广告展示时长最小值"`
	} `json:"ad_unit"`
	TotalNum int `json:"total_num" example:"总广告单元数据量"`
}

type GetAdposDetail struct {
	Ret    int    `json:"ret" example:"错误码"`
	ErrMsg string `json:"err_msg" example:"错误信息"`
	List   []struct {
		AdUnitId   string `json:"ad_unit_id" example:"广告单元ID"`
		AdUnitName string `json:"ad_unit_name" example:"广告单元名称"`
		AppId      string `json:"appid" example:"授权方 appid"`
		StatItem   struct {
			AdSlot          string  `json:"ad_slot" example:"广告位类型名称"`
			Date            string  `json:"date" example:"数据日期"`
			ExposureCount   int64   `json:"exposure_count" example:"曝光量"`
			ReqSuccCount    int64   `json:"req_succ_count" example:"拉取量"`
			PublisherIncome int64   `json:"publisher_income" example:"小程序分账收入(分)"`
			ClickCount      int64   `json:"click_count" example:"点击量"`
			Income          float64 `json:"income"`
			Ecpm            float64 `json:"ecpm" example:"广告千次曝光收益(分)"`
			ExposureRate    float64 `json:"exposure_rate" example:"曝光率"`
			ClickRate       float64 `json:"click_rate" example:"点击量"`
		} `json:"stat_item"`
	} `json:"list"`
	TotalNum int `json:"total_num" example:"请求返回总数"`
}

type AgencySetBlackListResp struct {
	Ret    int    `json:"ret"` // 错误码
	ErrMsg string `json:"err_msg" example:"错误信息"`
}

type AgencyGetBlackListResp struct {
	Ret          int    `json:"ret"` // 错误码
	ErrMsg       string `json:"err_msg" example:"错误信息"`
	BlacklistBiz []struct {
		Id   string `json:"id" example:"屏蔽公众号微信号"`
		Name string `json:"name" example:"屏蔽公众号名称"`
		Url  string `json:"url" example:"屏蔽公众号头像URL"`
	} `json:"blacklist_biz"` // 屏蔽公众号列表
	BlacklistWeapp []struct {
		Id   string `json:"id" example:"屏蔽小程序/小游戏原始ID"`
		Name string `json:"name" example:"屏蔽小程序/小游戏名称"`
		Url  string `json:"url" example:"屏蔽小程序/小游戏头像URL"`
	} `json:"blacklist_weapp"` // 屏蔽小程序/小游戏列表
	BlacklistIos []struct {
		Id   string `json:"id" example:"屏蔽IOS应用的APPID"`
		Name string `json:"name" example:"屏蔽IOS应用名称"`
		Url  string `json:"url" example:"屏蔽IOS应用标识图片"`
	} `json:"blacklist_ios"` // 屏蔽IOS应用列表
	BlacklistAndroid []struct {
		Id   string `json:"id" example:"屏蔽安卓应用的应用宝包名"`
		Name string `json:"name" example:"屏蔽安卓应用的名称"`
		Url  string `json:"url" example:"屏蔽安卓应用标识图片"`
	} `json:"blacklist_android"` // 屏蔽安卓应用列表
}

type SetAmsCategoryBlackListResp struct {
	Ret    int    `json:"ret" example:"错误码"`
	ErrMsg string `json:"err_msg" example:"错误信息"`
}

type GetAmsCategoryBlackListResp struct {
	Ret         int    `json:"ret" example:"错误码"`
	ErrMsg      string `json:"err_msg" example:"错误信息"`
	AmsCategory string `json:"ams_category" example:"屏蔽的行业类别"`
}
