package svc

import (
	"applet/app/e"
	"applet/app/lib/wechat"
	"applet/app/md"
	"applet/app/utils"
	"applet/app/utils/cache"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_mq.git/rabbit"
	db "code.fnuoos.com/zhimeng/model.git/src"
	implement2 "code.fnuoos.com/zhimeng/model.git/src/implement"
	model2 "code.fnuoos.com/zhimeng/model.git/src/model"
	"code.fnuoos.com/zhimeng/model.git/src/super/implement"
	"code.fnuoos.com/zhimeng/model.git/src/super/model"
	"errors"
	"fmt"
	"github.com/gin-gonic/gin"
	"strings"
)

func DataCenterOriginalDataList(c *gin.Context, req md.DataCenterOriginalDataReq) md.DataCenterOriginalDataRes {
	engine := db.Db
	NewOriginalWxAdDataDb := implement.NewOriginalWxAdDataDb(engine)
	appId := GetAppletId(c, req.Name, req.Platform)
	slotId := GetSlotId(c, req.State)
	MediumList, total, _ := NewOriginalWxAdDataDb.FindOriginalWxAdDataList(c.GetString("mid"), appId, slotId, req.StartTime, req.EndTime, utils.StrToInt(req.Page), utils.StrToInt(req.Limit))
	data := make([]md.DataCenterOriginalDataData, 0)
	if len(MediumList) > 0 {
		for _, v := range MediumList {
			var tmp = md.DataCenterOriginalDataData{
				Id:              utils.IntToStr(v.Id),
				ReqSuccCount:    utils.IntToStr(v.ReqSuccCount),
				ExposureCount:   utils.IntToStr(v.ExposureCount),
				ExposureRate:    v.ExposureRate,
				ClickCount:      utils.IntToStr(v.ClickCount),
				ClickRate:       v.ClickRate,
				Date:            v.Date,
				PublisherIncome: utils.Float64ToStr(float64(v.PublisherIncome) / 100),
				Ecpm:            utils.Float64ToStr(utils.StrToFloat64(v.Ecpm) / 100),
				IsApply:         utils.IntToStr(v.IsApply),
			}
			tmpApplet := GetAppletInfo(c, v.AppId)
			if tmpApplet["platform"] != "" {
				tmp.Platform = tmpApplet["platform"]
			}
			if tmpApplet["name"] != "" {
				tmp.Name = tmpApplet["name"]
			}
			tmpSlot := GetSlotInfo(c, v.SlotId)
			if tmpSlot["state"] != "" {
				tmp.State = tmpSlot["state"]
			}
			if tmpSlot["name"] != "" {
				tmp.AdvName = tmpSlot["name"]
			}
			data = append(data, tmp)
		}
	}
	res := md.DataCenterOriginalDataRes{
		List:     data,
		Total:    total,
		State:    md.AdState,
		Platform: md.AdPlatform,
	}
	return res
}
func DataCenterOriginalDataDel(c *gin.Context, req md.DataCenterOriginalDataCommReq) error {
	NewOriginalWxAdDataDb := implement.NewOriginalWxAdDataDb(db.Db)
	data, _ := NewOriginalWxAdDataDb.GetOriginalWxAdData(utils.StrToInt(req.Id))
	if data == nil {
		return errors.New("记录不存在")
	}
	if data.IsApply == 1 {
		return errors.New("记录已应用，不能删除")
	}
	_, err := db.Db.Where("id=?", req.Id).Delete(&model.OriginalWxAdData{})
	if err != nil {
		return err
	}
	return nil
}
func OriginalDataMoreApplication(c *gin.Context, req md.DataCenterOriginalDataMoreApplicationReq) md.DataCenterOriginalDataMoreApplicationRes {
	engine := MasterDb(c)
	NewAppletApplicationAdSpaceListDb := implement2.NewAppletApplicationAdSpaceListDb(engine)
	MediumList, total, _ := NewAppletApplicationAdSpaceListDb.FindAppletApplicationAdSpaceList(req.Name, "", "", "", 0, utils.StrToInt(req.Page), utils.StrToInt(req.Limit))
	data := make([]md.DataCenterOriginalDataMoreApplicationData, 0)
	if len(MediumList) > 0 {
		for _, v := range MediumList {
			var tmp = md.DataCenterOriginalDataMoreApplicationData{
				Id:      utils.IntToStr(v.AppletApplicationAdSpaceList.Id),
				AppId:   v.AppletApplicationAdSpaceList.AppId,
				AdId:    v.AppletApplicationAdSpaceList.AdId,
				Logo:    v.AppletApplication.Logo,
				Name:    v.AppletApplication.Name,
				State:   utils.IntToStr(v.AppletApplicationAdSpaceList.State),
				AdvName: v.AppletApplicationAdSpaceList.Name,
			}
			data = append(data, tmp)
		}
	}
	res := md.DataCenterOriginalDataMoreApplicationRes{
		List:  data,
		Total: total,
		State: md.AdState,
	}
	return res
}
func OriginalDataOneApplication(c *gin.Context) {
	list := make([]md.DataCenterOriginalDataOneApplicationData, 0)
	NewAppletApplicationDb := implement2.NewAppletApplicationDb(MasterDb(c))
	applicationList, _ := NewAppletApplicationDb.FindAllAppletApplicationList()
	for _, v := range applicationList {
		tmp := md.DataCenterOriginalDataOneApplicationData{
			Id:    utils.IntToStr(v.Id),
			AppId: v.AppId,
			Logo:  v.Logo,
			Name:  v.Name,
		}
		list = append(list, tmp)
	}
	var res = md.DataCenterOriginalDataOneApplicationRes{
		List: list,
	}
	e.OutSuc(c, res, nil)
	return
}
func OriginalDataOneApplicationAdList(c *gin.Context, req md.DataCenterOriginalDataOneApplicationAdListReq) md.DataCenterOriginalDataOneApplicationAdListRes {
	list := make([]md.DataCenterOriginalDataOneApplicationAdListData, 0)
	NewAppletApplicationDb := implement2.NewAppletApplicationAdSpaceListDb(MasterDb(c))
	applicationList, _ := NewAppletApplicationDb.FindAllAppletApplicationAdSpaceListList(req.AppId)
	for _, v := range applicationList {
		tmp := md.DataCenterOriginalDataOneApplicationAdListData{
			Id:    utils.IntToStr(v.Id),
			AdId:  v.AdId,
			Name:  v.Name,
			State: utils.IntToStr(v.State),
		}
		list = append(list, tmp)
	}
	var res = md.DataCenterOriginalDataOneApplicationAdListRes{
		List:  list,
		State: md.AdState,
	}
	return res
}
func DataCenterOriginalDataTotal(c *gin.Context, req md.DataCenterOriginalDataCommReq) {
	NewOriginalWxAdDataDb := implement.NewOriginalWxAdDataDb(db.Db)
	data, _ := NewOriginalWxAdDataDb.GetOriginalWxAdData(utils.StrToInt(req.Id))
	if data == nil {
		e.OutErr(c, 400, e.NewErr(400, "记录不存在"))
		return
	}
	//应用
	NewAppletApplicationDb := implement2.NewAppletApplicationDb(MasterDb(c))
	appid, _ := NewAppletApplicationDb.GetAppletApplicationListByAppid(data.AppId)
	if appid == nil {
		e.OutErr(c, 400, e.NewErr(400, "应用不存在"))
		return
	}
	//分成策略
	NewMediumDivisionStrategyDb := implement.NewMediumDivisionStrategyDb(db.Db)
	strategy, _ := NewMediumDivisionStrategyDb.GetOriginalWxAdDataByMediumId(appid.MediumId)
	if strategy == nil {
		e.OutErr(c, 400, e.NewErr(400, "分成策略不存在"))
		return
	}
	ecpmReq := md.ClacEcpmReq{
		OriginalExposureCount: data.ExposureCount,
		OriginalEcpm:          data.Ecpm,
		GenerateDataId:        data.Id,
	}
	_, ecpm := ClacEcpm(ecpmReq)

	res := md.MediumDivisionStrategy{
		PlatformRetentionRate:   utils.IntToStr(strategy.PlatformRetentionRate),
		CommissionRetentionRate: utils.IntToStr(strategy.CommissionRetentionRate),
		MediaRevenueRate:        utils.IntToStr(strategy.MediaRevenueRate),
		AgentRevenueRate:        utils.IntToStr(strategy.AgentRevenueRate),
		ExtraRevenueRate:        utils.IntToStr(strategy.ExtraRevenueRate),
		AgreementSharingRate:    utils.IntToStr(strategy.AgreementSharingRate),
		ExposureCount:           utils.IntToStr(data.ExposureCount),
		Ecpm:                    utils.Float64ToStr(utils.StrToFloat64(ecpm) / 100),
		OldEcpm:                 utils.Float64ToStr(utils.StrToFloat64(data.Ecpm) / 100),
	}
	e.OutSuc(c, res, nil)
	return
}
func DataCenterOriginalDataDoing(c *gin.Context, req md.DataCenterDataCenterOriginalDataDoingReq) error {
	NewOriginalWxAdDataDb := implement.NewOriginalWxAdDataDb(db.Db)
	data, _ := NewOriginalWxAdDataDb.GetOriginalWxAdData(utils.StrToInt(req.Id))
	if data == nil {
		return e.NewErr(400, "记录不存在")
	}
	if data.IsApply == 1 {
		return e.NewErr(400, "该记录已完成操作")
	}
	// 加锁 防止并发提取
	mutexKey := fmt.Sprintf("%s:DataCenterOriginalDataDoing:%s", c.GetString("mid"), req.Id)
	withdrawAvailable, err := cache.Do("SET", mutexKey, 1, "EX", 5, "NX")
	if err != nil {
		return err
	}
	if withdrawAvailable != "OK" {
		return e.NewErr(400000, "请求过于频繁，请稍后再试")
	}
	args := md.GenerateWxAdData{
		OriginalDataId:        utils.StrToInt(req.Id),
		OriginalExposureCount: data.ExposureCount,
		OriginalEcpm:          data.Ecpm,
		NowExposureCount:      utils.StrToInt(req.NowExposureCount),
		NowEcpm:               utils.Float64ToStr(utils.StrToFloat64(req.NowEcpm) * 100),
	}
	err, _ = GenerateWxAdData(args)
	if err != nil {
		return err
	}
	return nil
}
func OriginalDataMoreApplicationDoing(c *gin.Context, req md.DataCenterOriginalDataMoreApplicationDoingReq) error {
	//state, _ := cache.GetString(c.GetString("mid") + ":original.wx.ad.data")
	//if state == "1" {
	//	return e.NewErr(400000, "数据采集中~")
	//}
	// 加锁 防止并发提取
	mutexKey := fmt.Sprintf("%s:DataCenterOriginalDataDoingOriginalDataMoreApplicationDoing", c.GetString("mid"))
	withdrawAvailable, err := cache.Do("SET", mutexKey, 1, "EX", 5, "NX")
	if err != nil {
		return err
	}
	if withdrawAvailable != "OK" {
		return e.NewErr(400000, "请求过于频繁，请稍后再试")
	}
	ch, err := rabbit.Cfg.Pool.GetChannel()
	if err != nil {
		return err
	}
	defer ch.Release()
	ids := make([]md.DataCenterOriginalDataOneApplicationDoingReqData, 0)

	for _, v := range req.Ids {
		count, _ := db.Db.Where("uuid=? and date=? and app_id=? and slot_id=?", c.GetString("mid"), req.Date, v.AppId, v.AdId).Count(&model.OriginalWxAdData{})
		if count > 0 {
			continue
		}
		ids = append(ids, v)
	}
	masterId := GetMasterId(c)
	userWxAppletListDb := implement.NewUserWxAppletListDb(db.Db)
	UserWxAppletList, err := userWxAppletListDb.GetUserWxAppletList(masterId)
	if err != nil {
		return e.NewErr(400000, err.Error())
	}
	if UserWxAppletList == nil {
		return e.NewErr(400000, "未查询到对应记录")
	}
	wxOpenThirdPartyAppListDb := implement.NewWxOpenThirdPartyAppListDb(db.Db)
	wxOpenThirdPartyAppList, err := wxOpenThirdPartyAppListDb.GetWxOpenThirdPartyAppList(utils.StrToInt(masterId))
	if err != nil {
		return e.NewErr(400000, err.Error())
	}
	if wxOpenThirdPartyAppList == nil {
		return e.NewErr(400000, "未查询到对应三方应用记录")
	}
	for k, v := range ids {
		var arg = md.ZhiosAdOriginalDataApplication{
			Mid:                c.GetString("mid"),
			AppId:              v.AppId,
			AdId:               v.AdId,
			Date:               req.Date,
			ComponentAppid:     wxOpenThirdPartyAppList.Appid,
			ComponentAppsecret: wxOpenThirdPartyAppList.AppSecret,
		}
		if k+1 == len(req.Ids) {
			arg.IsEnd = "1"
		}
		err := ch.PublishV2(md.AdOriginalData, utils.SerializeStr(arg), md.AdOriginalDataApplication)
		if err != nil {
			ch.PublishV2(md.AdOriginalData, utils.SerializeStr(arg), md.AdOriginalDataApplication)
		}
	}
	if len(ids) == 0 {
		return e.NewErr(400000, "选择的广告位已存在,请删除后再生成")
	}
	cache.SetEx(c.GetString("mid")+":original.wx.ad.data", "1", 3600)
	return nil
}
func OriginalDataOneApplicationTotal(c *gin.Context, req md.DataCenterOriginalDataOneApplicationDoingReq) {
	//1、查找对应 user_wx_applet_list 记录
	userWxAppletListDb := implement.NewUserWxAppletListDb(db.Db)
	masterId := c.GetString("mid")
	UserWxAppletList, err := userWxAppletListDb.GetUserWxAppletList(masterId)
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err.Error())
		return
	}
	if UserWxAppletList == nil {
		e.OutErr(c, e.ERR_NO_DATA, "未查询到对应记录")
		return
	}
	wxOpenThirdPartyAppListDb := implement.NewWxOpenThirdPartyAppListDb(db.Db)
	wxOpenThirdPartyAppList, err := wxOpenThirdPartyAppListDb.GetWxOpenThirdPartyAppList(utils.StrToInt(masterId))
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	if wxOpenThirdPartyAppList == nil {
		e.OutErr(c, e.ERR_NOT_FAN, "未查询到对应三方应用记录")
		return
	}
	wxApiService, err := wechat.NewWxApiService(masterId, wxOpenThirdPartyAppList.Appid, wxOpenThirdPartyAppList.AppSecret)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	err, args := wxApiService.GetAdposDetail(req.AppId, 1, 1, req.Date, req.Date, req.AdId)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	var res = md.DataCenterOriginalDataOneApplicationDoingRes{}
	for _, v := range args.List {
		res = md.DataCenterOriginalDataOneApplicationDoingRes{
			AdId:            v.AdUnitId,
			AdSlot:          v.StatItem.AdSlot,
			ExposureCount:   utils.Int64ToStr(v.StatItem.ExposureCount),
			ReqSuccCount:    utils.Int64ToStr(v.StatItem.ReqSuccCount),
			PublisherIncome: utils.Float64ToStr(float64(v.StatItem.PublisherIncome) / 100),
			ClickCount:      utils.Int64ToStr(v.StatItem.ClickCount),
			Ecpm:            utils.Float64ToStr(v.StatItem.Ecpm / 100),
			ExposureRate:    utils.Float64ToStr(v.StatItem.ExposureRate),
			ClickRate:       utils.Float64ToStr(v.StatItem.ClickRate),
		}
	}
	e.OutSuc(c, res, nil)
	return
}

// 应用
func GetAppletId(c *gin.Context, name, platform string) string {
	mediumId := ""
	sess := MasterDb(c).Where("1=1")
	if name != "" || platform != "" {
		ids := []string{"-1"}
		var tmp []model2.AppletApplication
		if name != "" {
			sess.And("name like ? ", "%"+name+"%")
		}
		if platform != "" {
			sess.And("platform = ? ", platform)
		}
		sess.Find(&tmp)
		for _, v := range tmp {
			ids = append(ids, utils.IntToStr(v.MediumId))
		}
		mediumId = strings.Join(ids, ",")
	}
	return mediumId
}

// 广告位
func GetSlotId(c *gin.Context, state string) string {
	mediumId := ""
	if state != "" {
		ids := []string{"-1"}
		var tmp []model2.AppletApplicationAdSpaceList
		MasterDb(c).Where("state=?", state).Find(&tmp)
		for _, v := range tmp {
			ids = append(ids, utils.IntToStr(v.MediumId))
		}
		mediumId = strings.Join(ids, ",")
	}
	return mediumId
}

// 应用
func GetAppletInfo(c *gin.Context, id string) map[string]string {
	var res = map[string]string{
		"platform": "",
		"name":     "",
	}
	NewAppletApplicationDb := implement2.NewAppletApplicationDb(MasterDb(c))
	data, _ := NewAppletApplicationDb.GetAppletApplicationListByAppid(id)
	if data != nil {
		res["platform"] = data.Platform
		res["name"] = data.Name
	}
	return res
}

// 广告位
func GetSlotInfo(c *gin.Context, id string) map[string]string {
	var res = map[string]string{
		"state": "",
		"name":  "",
	}
	NewAppletApplicationAdSpaceListDb := implement2.NewAppletApplicationAdSpaceListDb(MasterDb(c))
	data, _ := NewAppletApplicationAdSpaceListDb.GetAppletApplicationAdSpaceListByAdId(id)
	if data != nil {
		res["name"] = data.Name
		res["state"] = utils.IntToStr(data.State)
	}
	return res
}
